Learn R Programming

Omisc (version 0.1.2)

HoffPseudoStandard: HoffPseudoStandard

Description

HoffPseudoStandard

Usage

HoffPseudoStandard(betas, SDX, interceptvar)

Arguments

betas

A vector of betas from a multilevel model

SDX

A vector of the standard deviations of the X value for each of the X's associated with the bets

interceptvar

A vector of the intercept variances at the level associated with the betas

Value

A vector of pseudostandardized coefficients

Examples

Run this code
# NOT RUN {
print("none")
# }

Run the code above in your browser using DataLab