powered by
HoffPseudoStandard
HoffPseudoStandard(betas, SDX, interceptvar)
A vector of betas from a multilevel model
A vector of the standard deviations of the X value for each of the X's associated with the bets
A vector of the intercept variances at the level associated with the betas
A vector of pseudostandardized coefficients
# NOT RUN { print("none") # }
Run the code above in your browser using DataLab